# Release Notes
---

## [1.4.4](https://github.com/osl-incubator/containers-sugar/compare/1.4.3...1.4.4) (2023-04-05)


### Bug Fixes

* Fix the internal usage of the value from --cmd flag ([#67](https://github.com/osl-incubator/containers-sugar/issues/67)) ([ac8a048](https://github.com/osl-incubator/containers-sugar/commit/ac8a0487f41404c52195cfcf74fa18a86f4523f8))

## [1.4.3](https://github.com/osl-incubator/containers-sugar/compare/1.4.2...1.4.3) (2023-03-25)


### Bug Fixes

* Remove --volumes from down command ([#66](https://github.com/osl-incubator/containers-sugar/issues/66)) ([8bcaae4](https://github.com/osl-incubator/containers-sugar/commit/8bcaae47fb413f682337759a7f5cab152ee83e76))

## [1.4.2](https://github.com/osl-incubator/containers-sugar/compare/1.4.1...1.4.2) (2023-03-08)


### Bug Fixes

* Fix the exit function when an error happens ([#64](https://github.com/osl-incubator/containers-sugar/issues/64)) ([6305cd8](https://github.com/osl-incubator/containers-sugar/commit/6305cd8189b2745c56c87f80c53f118965358226))

## [1.4.1](https://github.com/osl-incubator/containers-sugar/compare/1.4.0...1.4.1) (2023-02-15)


### Bug Fixes

* Use extras for all sub-commands ([#38](https://github.com/osl-incubator/containers-sugar/issues/38)) ([41abdeb](https://github.com/osl-incubator/containers-sugar/commit/41abdebc51c24cd1d4739c66d9595b8dd404c355))

# [1.4.0](https://github.com/osl-incubator/containers-sugar/compare/1.3.2...1.4.0) (2023-02-09)


### Features

* Add support for multiples compose-path ([#37](https://github.com/osl-incubator/containers-sugar/issues/37)) ([c726250](https://github.com/osl-incubator/containers-sugar/commit/c7262501235453641adbf735d93be9bed22193a6))

## [1.3.2](https://github.com/osl-incubator/containers-sugar/compare/1.3.1...1.3.2) (2023-02-09)


### Bug Fixes

* Fix the argument `--all` ([#34](https://github.com/osl-incubator/containers-sugar/issues/34)) ([747a1c0](https://github.com/osl-incubator/containers-sugar/commit/747a1c021e55de753f4f28ad3dc4cb49c7f5ce01))

## [1.3.1](https://github.com/osl-incubator/containers-sugar/compare/1.3.0...1.3.1) (2023-02-07)


### Bug Fixes

* Fix --extras parameter and improve the CI ([#32](https://github.com/osl-incubator/containers-sugar/issues/32)) ([9340712](https://github.com/osl-incubator/containers-sugar/commit/9340712a9a9c65c07f9ff9ad732a47f6d3dc0d0d))

# [1.3.0](https://github.com/osl-incubator/containers-sugar/compare/1.2.0...1.3.0) (2023-02-07)


### Features

* Add extra args and command argument for run and exec action ([#31](https://github.com/osl-incubator/containers-sugar/issues/31)) ([e942183](https://github.com/osl-incubator/containers-sugar/commit/e94218374632e98839c49e62a288c7618fe10b43))

# [1.2.0](https://github.com/osl-incubator/containers-sugar/compare/1.1.0...1.2.0) (2023-02-06)


### Features

* Add extra args and command argument for run and exec action ([#27](https://github.com/osl-incubator/containers-sugar/issues/27)) ([8680799](https://github.com/osl-incubator/containers-sugar/commit/8680799ae7bdbbe57281180f0bd2d2461445cbbc))

# [1.1.0](https://github.com/osl-incubator/containers-sugar/compare/1.0.6...1.1.0) (2023-01-27)


### Features

* Add run and exec initial implementation ([#21](https://github.com/osl-incubator/containers-sugar/issues/21)) ([332f2bc](https://github.com/osl-incubator/containers-sugar/commit/332f2bce7d7c6945707ffe128619bc9bda2b8548))

## [1.0.6](https://github.com/osl-incubator/containers-sugar/compare/1.0.5...1.0.6) (2023-01-27)


### Bug Fixes

* Fix env-file access and improve version sub-command output ([#17](https://github.com/osl-incubator/containers-sugar/issues/17)) ([bc50bb9](https://github.com/osl-incubator/containers-sugar/commit/bc50bb9b2d7dcaf87e847f794c296b82dff7a4e9))

## [1.0.5](https://github.com/osl-incubator/containers-sugar/compare/1.0.4...1.0.5) (2023-01-26)


### Bug Fixes

* Fix the import of sh lib and add pre-commit run to CI ([#16](https://github.com/osl-incubator/containers-sugar/issues/16)) ([ac048e1](https://github.com/osl-incubator/containers-sugar/commit/ac048e189ecf553277246f34fa9b6f67010dc7ca))

## [1.0.4](https://github.com/osl-incubator/containers-sugar/compare/1.0.3...1.0.4) (2023-01-26)


### Bug Fixes

* Fix the sh call ([#15](https://github.com/osl-incubator/containers-sugar/issues/15)) ([6e26308](https://github.com/osl-incubator/containers-sugar/commit/6e263088458ece50bd66d9a3575ed5d0cec51f8a))

## [1.0.3](https://github.com/osl-incubator/containers-sugar/compare/1.0.2...1.0.3) (2023-01-26)


### Bug Fixes

* Suppress traceback from sh ([#14](https://github.com/osl-incubator/containers-sugar/issues/14)) ([69902c6](https://github.com/osl-incubator/containers-sugar/commit/69902c6372ec55cc36bbdd87e0f594c733163886))

## [1.0.2](https://github.com/osl-incubator/containers-sugar/compare/1.0.1...1.0.2) (2023-01-26)


### Bug Fixes

* Fix support for python 3.7.1, 3.8, 3.9, 3.10 ([#13](https://github.com/osl-incubator/containers-sugar/issues/13)) ([83a9592](https://github.com/osl-incubator/containers-sugar/commit/83a9592e06b7fabc7a0f260b38a58267488a070e))

## [1.0.1](https://github.com/osl-incubator/containers-sugar/compare/1.0.0...1.0.1) (2023-01-21)


### Bug Fixes

* Fix quotes used by semantic release replace ([#8](https://github.com/osl-incubator/containers-sugar/issues/8)) ([66acb67](https://github.com/osl-incubator/containers-sugar/commit/66acb67b9275a2afea48b6dd97b143edfff80be1))
